#############
API reference
#############

..
    to document functions, add them to __all__ in ../src/xsar/__init__.py

.. automodule:: xsar
    :members: open_dataset, product_info

Base classes
============
.. automodule:: xsar
    :members: BaseMeta, BaseDataset

XSAR Meta classes
=================
.. automodule:: xsar
    :members: Sentinel1Meta, RadarSat2Meta

XSAR Dataset classes
====================
.. automodule:: xsar
    :members: Sentinel1Dataset, RadarSat2Dataset


